==> pytest-unflakable-0.1.0.tar.gz: pytest-unflakable-0.1.0/README.md <==
<p align="center">
  <a href="https://unflakable.com" target="_blank" rel="noopener" align="center">
    <img src="https://github.com/unflakable/unflakable-python/blob/main/images/logo.svg?raw=true" width="350" alt="Unflakable" />
  </a>
</p>

[![Twitter](https://img.shields.io/twitter/url?label=%40unflakable&style=social&url=https%3A%2F%2Ftwitter.com%2Funflakable)](https://twitter.com/unflakable)

# Official Unflakable Plugins for Python

This repository contains the official [Unflakable](https://unflakable.com) plugins for Python.

## Getting Started

Refer to our [Getting Started](https://docs.unflakable.com/getting-started) documentation
for instructions on getting started using Unflakable.

## PyTest Plugin

This Unflakable plugin enables users of the [PyTest](https://pytest.org) Python test framework
to quarantine flaky tests and track test results.

Refer to the [PyTest Plugin](https://docs.unflakable.com/plugins/pytest) documentation for
complete usage instructions. Users of the Python
[`unittest` unit testing framework](https://docs.python.org/3/library/unittest.html) may use this
plugin by leveraging PyTest's [out-of-the-box support](https://docs.pytest.org/how-to/unittest.html)
for running `unittest` tests.

### Compatibility

This plugin maintains compatibility with the PyTest and Python versions listed below:

![Python versions](https://img.shields.io/pypi/pyversions/pytest-unflakable)
![PyTest versions](https://img.shields.io/badge/pytest-6.2%20%7C%207.0%20%7C%207.1-blue)

## Contributing

To report a bug or request a new feature, please
[file a GitHub issue](https://github.com/unflakable/unflakable-python/issues).
We also welcome pull requests!

==> pytest-unflakable-0.1.2.tar.gz: pytest-unflakable-0.1.2/README.md <==
<p align="center">
  <a href="https://unflakable.com" target="_blank" rel="noopener" align="center">
    <img src="https://github.com/unflakable/unflakable-python/blob/main/images/logo.svg?raw=true" width="350" alt="Unflakable" />
  </a>
</p>

[![Twitter](https://img.shields.io/twitter/url?label=%40unflakable&style=social&url=https%3A%2F%2Ftwitter.com%2Funflakable)](https://twitter.com/unflakable)

# Official Unflakable Plugins for Python

This repository contains the official [Unflakable](https://unflakable.com) plugins for Python.

## Getting Started

Refer to our [Getting Started](https://docs.unflakable.com/getting-started) documentation
for instructions on getting started using Unflakable.

## PyTest Plugin

[![PyPI version](https://img.shields.io/pypi/v/pytest-unflakable.svg)](https://pypi.org/project/pytest-unflakable)

This Unflakable plugin enables users of the [PyTest](https://pytest.org) Python test framework
to quarantine flaky tests and track test results.

Refer to the [PyTest Plugin](https://docs.unflakable.com/plugins/pytest) documentation for
complete usage instructions. Users of the Python
[`unittest` unit testing framework](https://docs.python.org/3/library/unittest.html) may use this
plugin by leveraging PyTest's [out-of-the-box support](https://docs.pytest.org/how-to/unittest.html)
for running `unittest` tests.

### Compatibility

This plugin maintains compatibility with the PyTest and Python versions listed below:

![Python versions](https://img.shields.io/pypi/pyversions/pytest-unflakable)
![PyTest versions](https://img.shields.io/badge/pytest-6.2%20%7C%207.0%20%7C%207.1-blue)

## Contributing

To report a bug or request a new feature, please
[file a GitHub issue](https://github.com/unflakable/unflakable-python/issues).
We also welcome pull requests!
